@@ -190,7 +190,12 @@ class DemoServer(Server):
 
     def _render_tms_template(self, template, req):
         template = get_template(template, default_inherit="demo/static.html")
-        tile_layer = self.tile_layers['_'.join([req.args['tms_layer'], req.args['srs'].replace(':','')])]
+        for layer in self.tile_layers.values():
+            if (layer.name == req.args['tms_layer'] and
+                    layer.grid.srs.srs_code == req.args['srs']):
+                tile_layer = layer
+                break
+
         resolutions = tile_layer.grid.tile_sets
         res = []
         for level, resolution in resolutions:
@@ -215,7 +220,11 @@ class DemoServer(Server):
 
     def _render_wmts_template(self, template, req):
         template = get_template(template, default_inherit="demo/static.html")
-        wmts_layer = self.tile_layers['_'.join([req.args['wmts_layer'], req.args['srs'].replace(':','')])]
+        for layer in self.tile_layers.values():
+            if (layer.name == req.args['wmts_layer'] and
+                    layer.grid.srs.srs_code == req.args['srs']):
+                wmts_layer = layer
+                break
 
         restful_url = self.restful_template.replace('{Layer}', wmts_layer.name, 1)
         if '{Format}' in restful_url:
